==> haskell-hopenpgp-2.5.5-117-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.5.5
id: hOpenPGP-2.5.5-HcXo9yOk6QPJ5tbqpLBxuJ
key: hOpenPGP-2.5.5-HcXo9yOk6QPJ5tbqpLBxuJ
license: MIT
copyright: 2012-2016  Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/hOpenPGP/
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581)
category: Codec, Data
author: Clint Adams
exposed: True
indefinite: False
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
abi: b063f203884504ebc35f694d01e3dc61
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hOpenPGP-2.5.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/hOpenPGP-2.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hOpenPGP-2.5.5
hs-libraries: HShOpenPGP-2.5.5-HcXo9yOk6QPJ5tbqpLBxuJ
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm base-4.10.0.0
    base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH bytestring-0.10.8.2
    bzlib-0.5.0.5-2ACJ0eb5Hvh5CxJWPSOUm0 binary-0.8.5.1
    binary-conduit-1.2.5-J9at1kujPf6FQI2I4RaFVg
    conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1
    conduit-extra-1.1.17-LlNYIlAZHtT6LyG0bML71e containers-0.5.10.2
    cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi
    crypto-cipher-types-0.0.9-FlB3Fs34YAGKo4xKKfzPsc
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    errors-2.2.2-55dL44uoGvGA1pVVvEb4s7
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    incremental-parser-0.2.5.1-Jc25lee9wKUDsEraXZSeU
    ixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6
    lens-4.15.4-BVNSGosFkEc34U2t4uFumn
    memory-0.14.8-HEYe2msABjoBOvbV0yaOyF
    monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3
    nettle-0.2.0-AJVtKGpcXjM6REdlSTNCPy
    newtype-0.2-FGlcbwZJDWBDoQ1CjU9icp
    openpgp-asciiarmor-0.1-KViK2NI5FGw2nv7QR7YcSH
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    wl-pprint-extras-3.5.0.5-G9dZC3rqH9tFXqH3RBpGbU
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko=b289e975ce7bd8a34701a798ad869335
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE=9b3f7bc028399697ef969074e342f279
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=d344f7951d5abb0484f8cf34bb5d3e34
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             bzlib-0.5.0.5-2ACJ0eb5Hvh5CxJWPSOUm0=87470a0806c0eb3fa29f04c30f51e049
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             binary-conduit-1.2.5-J9at1kujPf6FQI2I4RaFVg=288d239bb8c2c3696decee9f6c8ecf4b
             conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1=60ad65370a9da57d3d90715264a4baf8
             conduit-extra-1.1.17-LlNYIlAZHtT6LyG0bML71e=8535fcdffdc059c10de789d083424da6
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi=1928ece35e67ec41b499da4f70bba50f
             crypto-cipher-types-0.0.9-FlB3Fs34YAGKo4xKKfzPsc=b9ac2fef46ec6adf6264e10e0e16963b
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=55d8edbe337279f21d58496f3f779cb9
             errors-2.2.2-55dL44uoGvGA1pVVvEb4s7=6f91e0aa3a7d85f06b19237b3848b658
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             incremental-parser-0.2.5.1-Jc25lee9wKUDsEraXZSeU=15fc21386406b0ac7df8c4958548303c
             ixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6=3ad3f74bc1f3db226704caa42b934c2f
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=693a07eed940cac4dd3dec3341ea8baa
             memory-0.14.8-HEYe2msABjoBOvbV0yaOyF=4c821a304108f2b075d812c81435d53c
             monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3=54591a587aa7d5d988ebd34e65b8f537
             nettle-0.2.0-AJVtKGpcXjM6REdlSTNCPy=622d9a6e83055c2b86db4b0ba647f69e
             newtype-0.2-FGlcbwZJDWBDoQ1CjU9icp=40ef982b20c826289bcad285b879d30c
             openpgp-asciiarmor-0.1-KViK2NI5FGw2nv7QR7YcSH=7d9d029b0ab69074729a2500a1ee6bec
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE=b794206c4979d66a34cacb4bf5e5db43
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe=a6d1338097cefdc7bd8b7f2e3d3d2459
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             wl-pprint-extras-3.5.0.5-G9dZC3rqH9tFXqH3RBpGbU=d6c2e4feb509b6bf14cbb07435d2d040
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=c1d55c3251ed960ccd96b402a1d90259
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hopenpgp-2.5.5-118-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.5.5
id: hOpenPGP-2.5.5-KsqFiwV5pcmDwF0Jdogns0
key: hOpenPGP-2.5.5-KsqFiwV5pcmDwF0Jdogns0
license: MIT
copyright: 2012-2016  Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/hOpenPGP/
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581)
category: Codec, Data
author: Clint Adams
exposed: True
indefinite: False
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
abi: 659c4f2c9827b84ebcc7dd09198b5383
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hOpenPGP-2.5.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/hOpenPGP-2.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hOpenPGP-2.5.5
hs-libraries: HShOpenPGP-2.5.5-KsqFiwV5pcmDwF0Jdogns0
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm base-4.10.0.0
    base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH bytestring-0.10.8.2
    bzlib-0.5.0.5-2ACJ0eb5Hvh5CxJWPSOUm0 binary-0.8.5.1
    binary-conduit-1.2.5-31EyZVzgu87DUNvMVFKqfl
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK containers-0.5.10.2
    cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi
    crypto-cipher-types-0.0.9-FlB3Fs34YAGKo4xKKfzPsc
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    errors-2.2.2-55dL44uoGvGA1pVVvEb4s7
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    incremental-parser-0.2.5.1-Jc25lee9wKUDsEraXZSeU
    ixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6
    lens-4.15.4-BVNSGosFkEc34U2t4uFumn
    memory-0.14.8-HEYe2msABjoBOvbV0yaOyF
    monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3
    nettle-0.2.0-AJVtKGpcXjM6REdlSTNCPy
    newtype-0.2-FGlcbwZJDWBDoQ1CjU9icp
    openpgp-asciiarmor-0.1-KViK2NI5FGw2nv7QR7YcSH
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    wl-pprint-extras-3.5.0.5-G9dZC3rqH9tFXqH3RBpGbU
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko=b289e975ce7bd8a34701a798ad869335
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE=9b3f7bc028399697ef969074e342f279
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=d344f7951d5abb0484f8cf34bb5d3e34
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             bzlib-0.5.0.5-2ACJ0eb5Hvh5CxJWPSOUm0=87470a0806c0eb3fa29f04c30f51e049
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             binary-conduit-1.2.5-31EyZVzgu87DUNvMVFKqfl=4392526f1b5c3bfae6bf34a51b26976f
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=52e9aaa2724a9edb2ade5ee067f8810a
             conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK=56fd5c6de95125ae43c66f7b1cc14a76
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi=1928ece35e67ec41b499da4f70bba50f
             crypto-cipher-types-0.0.9-FlB3Fs34YAGKo4xKKfzPsc=b9ac2fef46ec6adf6264e10e0e16963b
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=55d8edbe337279f21d58496f3f779cb9
             errors-2.2.2-55dL44uoGvGA1pVVvEb4s7=6f91e0aa3a7d85f06b19237b3848b658
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             incremental-parser-0.2.5.1-Jc25lee9wKUDsEraXZSeU=15fc21386406b0ac7df8c4958548303c
             ixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6=3ad3f74bc1f3db226704caa42b934c2f
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=693a07eed940cac4dd3dec3341ea8baa
             memory-0.14.8-HEYe2msABjoBOvbV0yaOyF=4c821a304108f2b075d812c81435d53c
             monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3=54591a587aa7d5d988ebd34e65b8f537
             nettle-0.2.0-AJVtKGpcXjM6REdlSTNCPy=622d9a6e83055c2b86db4b0ba647f69e
             newtype-0.2-FGlcbwZJDWBDoQ1CjU9icp=40ef982b20c826289bcad285b879d30c
             openpgp-asciiarmor-0.1-KViK2NI5FGw2nv7QR7YcSH=7d9d029b0ab69074729a2500a1ee6bec
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE=b794206c4979d66a34cacb4bf5e5db43
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe=a6d1338097cefdc7bd8b7f2e3d3d2459
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             wl-pprint-extras-3.5.0.5-G9dZC3rqH9tFXqH3RBpGbU=d6c2e4feb509b6bf14cbb07435d2d040
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=c1d55c3251ed960ccd96b402a1d90259
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
